@@ -48,14 +48,30 @@ except ImportError:
         def emit(self, record):
             pass
 
-__version__ = '0.6.2'
+__version__ = '1.0.0'
 
 # Elasticsearch versions supported
-version_max  = (1, 0, 0)
-version_min = (0, 19, 4)
+version_max  = (2, 0, 0)
+version_min = (1, 0, 0)
         
 logger = logging.getLogger(__name__)
 
+DEFAULT_ARGS = {
+    'host': 'localhost',
+    'url_prefix': '',
+    'port': 9200,
+    'ssl': False,
+    'timeout': 30,
+    'prefix': 'logstash-',
+    'separator': '.',
+    'curation_style': 'time',
+    'time_unit': 'days',
+
+    'max_num_segments': 2,
+    'dry_run': False,
+    'debug': False,
+}
+
 def make_parser():
     """ Creates an ArgumentParser to parse the command line options. """
     help_desc = 'Curator for Elasticsearch indices.  Can delete (by space or time), close, disable bloom filters and optimize (forceMerge) your indices.'
@@ -69,29 +85,29 @@ def make_parser():
         parser.parse_args_orig = parser.parse_args
         parser.parse_args = lambda: parser.parse_args_orig()[0]
         parser.add_argument = parser.add_option
-    parser.add_argument('--host', help='Elasticsearch host. Default: localhost', default='localhost')
-    parser.add_argument('--url_prefix', help='Elasticsearch http url prefix. Default: none', default='')
-    parser.add_argument('--port', help='Elasticsearch port. Default: 9200', default=9200, type=int)
-    parser.add_argument('--ssl', help='Connect to Elasticsearch through SSL. Default: false', action='store_true', default=False)
-    parser.add_argument('-t', '--timeout', help='Elasticsearch timeout. Default: 30', default=30, type=int)
+    parser.add_argument('--host', help='Elasticsearch host. Default: localhost', default=DEFAULT_ARGS['host'])
+    parser.add_argument('--url_prefix', help='Elasticsearch http url prefix. Default: none', default=DEFAULT_ARGS['url_prefix'])
+    parser.add_argument('--port', help='Elasticsearch port. Default: 9200', default=DEFAULT_ARGS['port'], type=int)
+    parser.add_argument('--ssl', help='Connect to Elasticsearch through SSL. Default: false', action='store_true', default=DEFAULT_ARGS['ssl'])
+    parser.add_argument('-t', '--timeout', help='Elasticsearch timeout. Default: 30', default=DEFAULT_ARGS['timeout'], type=int)
 
-    parser.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default='logstash-')
-    parser.add_argument('-s', '--separator', help='Time unit separator. Default: .', default='.')
+    parser.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
+    parser.add_argument('-s', '--separator', help='Time unit separator. Default: .', default=DEFAULT_ARGS['separator'])
 
-    parser.add_argument('-C', '--curation-style', dest='curation_style', action='store', help='Curate indices by [time, space] Default: time', default='time', type=str)
-    parser.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default='days', type=str)
+    parser.add_argument('-C', '--curation-style', dest='curation_style', action='store', help='Curate indices by [time, space] Default: time', default=DEFAULT_ARGS['curation_style'], type=str)
+    parser.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
 
     parser.add_argument('-d', '--delete', dest='delete_older', action='store', help='Delete indices older than n TIME_UNITs.', type=int)
     parser.add_argument('-c', '--close', dest='close_older', action='store', help='Close indices older than n TIME_UNITs.', type=int)
     parser.add_argument('-b', '--bloom', dest='bloom_older', action='store', help='Disable bloom filter for indices older than n TIME_UNITs.', type=int)
     parser.add_argument('-g', '--disk-space', dest='disk_space', action='store', help='Delete indices beyond n GIGABYTES.', type=float)
 
-    parser.add_argument('--max_num_segments', action='store', help='Maximum number of segments, post-optimize. Default: 2', type=int, default=2)
+    parser.add_argument('--max_num_segments', action='store', help='Maximum number of segments, post-optimize. Default: 2', type=int, default=DEFAULT_ARGS['max_num_segments'])
     parser.add_argument('-o', '--optimize', action='store', help='Optimize (Lucene forceMerge) indices older than n TIME_UNITs.  Must increase timeout to stay connected throughout optimize operation, recommend no less than 3600.', type=int)
 
-    parser.add_argument('-n', '--dry-run', action='store_true', help='If true, does not perform any changes to the Elasticsearch indices.', default=False)
-    parser.add_argument('-D', '--debug', dest='debug', action='store_true', help='Debug mode', default=False)
-    parser.add_argument('-l', '--logfile', dest='log_file', help='log file', type=str, default=None)
+    parser.add_argument('-n', '--dry-run', action='store_true', help='If true, does not perform any changes to the Elasticsearch indices.', default=DEFAULT_ARGS['dry_run'])
+    parser.add_argument('-D', '--debug', dest='debug', action='store_true', help='Debug mode', default=DEFAULT_ARGS['debug'])
+    parser.add_argument('-l', '--logfile', dest='log_file', help='log file', type=str)
 
     return parser
 
@@ -147,16 +163,6 @@ def get_version(client):
     version = client.info()['version']['number']
     return tuple(map(int, version.split('.')))
 
-def can_bloom(client):
-    """Return True if ES version > 0.90.9"""
-    version_number = get_version(client)
-    # Bloom filter unloading not supported in versions < 0.90.9
-    if version_number >= (0, 90, 9):
-        return True
-    else:
-        logger.warn('Your Elasticsearch version {0} is too old to use the bloom filter disable feature. Requires 0.90.9+'.format(".".join(map(str,version_number))))
-        return False
-
 def find_expired_indices(client, time_unit, unit_count, separator='.', prefix='logstash-', utc_now=None):
     """ Generator that yields expired indices.
 
@@ -166,19 +172,19 @@ def find_expired_indices(client, time_unit, unit_count, separator='.', prefix='l
     """
     # time-injection for test purposes only
     utc_now = utc_now if utc_now else datetime.utcnow()
-    # reset to midnight to be sure we are not retiring a human by mistake
-    utc_now = utc_now.replace(hour=0, minute=0, second=0, microsecond=0)
+    # reset to start of the period to be sure we are not retiring a human by mistake
+    utc_now = utc_now.replace(minute=0, second=0, microsecond=0)
+
+    if time_unit == 'hours':
+        required_parts = 4
+    else:
+        required_parts = 3
+        utc_now = utc_now.replace(hour=0)
 
     cutoff = utc_now - timedelta(**{time_unit: unit_count})
-    required_parts = 4 if time_unit == 'hours' else 3
-
-    sorted_indices = sorted(client.indices.get_settings().keys())
+    sorted_indices = sorted(client.indices.get_settings(index=prefix+'*', params={'expand_wildcards': 'closed'}).keys())
 
     for index_name in sorted_indices:
-        if not index_name.startswith(prefix):
-            logger.debug('Skipping index due to missing prefix {0}: {1}'.format(prefix, index_name))
-            continue
-
         unprefixed_index_name = index_name[len(prefix):]
 
         # find the timestamp parts (i.e ['2011', '01', '05'] from '2011.01.05') using the configured separator
@@ -214,19 +220,17 @@ def find_overusage_indices(client, disk_space_to_keep, separator='.', prefix='lo
     disk_usage = 0.0
     disk_limit = disk_space_to_keep * 2**30
 
-    sorted_indices = sorted(client.indices.get_settings().keys(), reverse=True)
+    stats = client.indices.status(index=prefix+'*')
+    sorted_indices = sorted(
+        (
+            (index_name, index_stats['index']['primary_size_in_bytes'])
+            for (index_name, index_stats) in stats['indices'].items()
+        ),
+        reverse=True
+    )
 
-    for index_name in sorted_indices:
-
-        if not index_name.startswith(prefix):
-            logger.debug('Skipping index due to missing prefix {0}: {1}'.format(prefix, index_name))
-            continue
-
-        if not index_closed(client, index_name):
-            index_size = client.indices.status(index=index_name)['indices'][index_name]['index']['primary_size_in_bytes']
-            disk_usage += index_size
-        else:
-            logger.warn('Cannot check size of index {0} because it is closed.  Size estimates will not be accurate.')
+    for index_name, index_size in sorted_indices:
+        disk_usage += index_size
 
         if disk_usage > disk_limit:
             yield index_name, 0
@@ -237,11 +241,8 @@ def find_overusage_indices(client, disk_space_to_keep, separator='.', prefix='lo
 def index_closed(client, index_name):
     """Return True if index is closed"""
     index_metadata = client.cluster.state(
-        filter_blocks=True,
-        filter_index_templates=True,
-        filter_indices=index_name,
-        filter_nodes=True,
-        filter_routing_table=True,
+        index=index_name,
+        metric='metadata',
     )
     return index_metadata['metadata']['indices'][index_name]['state'] == 'close'
 
